==> client-java-api-7.0.0-sources.jar: io/kubernetes/client/openapi/models/V1WindowsSecurityContextOptionsFluentImpl.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1WindowsSecurityContextOptionsFluentImpl<A extends V1WindowsSecurityContextOptionsFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1WindowsSecurityContextOptionsFluent<A>{

    private String gmsaCredentialSpec;
    private String gmsaCredentialSpecName;

    public V1WindowsSecurityContextOptionsFluentImpl(){
    }
    public V1WindowsSecurityContextOptionsFluentImpl(V1WindowsSecurityContextOptions instance){
            this.withGmsaCredentialSpec(instance.getGmsaCredentialSpec());

            this.withGmsaCredentialSpecName(instance.getGmsaCredentialSpecName());

    }

    public String getGmsaCredentialSpec(){
            return this.gmsaCredentialSpec;
    }

    public A withGmsaCredentialSpec(String gmsaCredentialSpec){
            this.gmsaCredentialSpec=gmsaCredentialSpec; return (A) this;
    }

    public Boolean hasGmsaCredentialSpec(){
            return this.gmsaCredentialSpec != null;
    }

    public A withNewGmsaCredentialSpec(String arg1){
            return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(StringBuilder arg1){
            return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(StringBuffer arg1){
            return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public String getGmsaCredentialSpecName(){
            return this.gmsaCredentialSpecName;
    }

    public A withGmsaCredentialSpecName(String gmsaCredentialSpecName){
            this.gmsaCredentialSpecName=gmsaCredentialSpecName; return (A) this;
    }

    public Boolean hasGmsaCredentialSpecName(){
            return this.gmsaCredentialSpecName != null;
    }

    public A withNewGmsaCredentialSpecName(String arg1){
            return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(StringBuilder arg1){
            return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(StringBuffer arg1){
            return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            V1WindowsSecurityContextOptionsFluentImpl that = (V1WindowsSecurityContextOptionsFluentImpl) o;
            if (gmsaCredentialSpec != null ? !gmsaCredentialSpec.equals(that.gmsaCredentialSpec) :that.gmsaCredentialSpec != null) return false;
            if (gmsaCredentialSpecName != null ? !gmsaCredentialSpecName.equals(that.gmsaCredentialSpecName) :that.gmsaCredentialSpecName != null) return false;
            return true;
    }




}

==> client-java-api-8.0.0-sources.jar: io/kubernetes/client/openapi/models/V1WindowsSecurityContextOptionsFluentImpl.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1WindowsSecurityContextOptionsFluentImpl<A extends V1WindowsSecurityContextOptionsFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1WindowsSecurityContextOptionsFluent<A>{

    private String gmsaCredentialSpec;
    private String gmsaCredentialSpecName;
    private String runAsUserName;

    public V1WindowsSecurityContextOptionsFluentImpl(){
    }
    public V1WindowsSecurityContextOptionsFluentImpl(V1WindowsSecurityContextOptions instance){
            this.withGmsaCredentialSpec(instance.getGmsaCredentialSpec());

            this.withGmsaCredentialSpecName(instance.getGmsaCredentialSpecName());

            this.withRunAsUserName(instance.getRunAsUserName());

    }

    public String getGmsaCredentialSpec(){
            return this.gmsaCredentialSpec;
    }

    public A withGmsaCredentialSpec(String gmsaCredentialSpec){
            this.gmsaCredentialSpec=gmsaCredentialSpec; return (A) this;
    }

    public Boolean hasGmsaCredentialSpec(){
            return this.gmsaCredentialSpec != null;
    }

    public A withNewGmsaCredentialSpec(String arg1){
            return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(StringBuilder arg1){
            return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public A withNewGmsaCredentialSpec(StringBuffer arg1){
            return (A)withGmsaCredentialSpec(new String(arg1));
    }

    public String getGmsaCredentialSpecName(){
            return this.gmsaCredentialSpecName;
    }

    public A withGmsaCredentialSpecName(String gmsaCredentialSpecName){
            this.gmsaCredentialSpecName=gmsaCredentialSpecName; return (A) this;
    }

    public Boolean hasGmsaCredentialSpecName(){
            return this.gmsaCredentialSpecName != null;
    }

    public A withNewGmsaCredentialSpecName(String arg1){
            return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(StringBuilder arg1){
            return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public A withNewGmsaCredentialSpecName(StringBuffer arg1){
            return (A)withGmsaCredentialSpecName(new String(arg1));
    }

    public String getRunAsUserName(){
            return this.runAsUserName;
    }

    public A withRunAsUserName(String runAsUserName){
            this.runAsUserName=runAsUserName; return (A) this;
    }

    public Boolean hasRunAsUserName(){
            return this.runAsUserName != null;
    }

    public A withNewRunAsUserName(String arg1){
            return (A)withRunAsUserName(new String(arg1));
    }

    public A withNewRunAsUserName(StringBuilder arg1){
            return (A)withRunAsUserName(new String(arg1));
    }

    public A withNewRunAsUserName(StringBuffer arg1){
            return (A)withRunAsUserName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            V1WindowsSecurityContextOptionsFluentImpl that = (V1WindowsSecurityContextOptionsFluentImpl) o;
            if (gmsaCredentialSpec != null ? !gmsaCredentialSpec.equals(that.gmsaCredentialSpec) :that.gmsaCredentialSpec != null) return false;
            if (gmsaCredentialSpecName != null ? !gmsaCredentialSpecName.equals(that.gmsaCredentialSpecName) :that.gmsaCredentialSpecName != null) return false;
            if (runAsUserName != null ? !runAsUserName.equals(that.runAsUserName) :that.runAsUserName != null) return false;
            return true;
    }




}
